@@ -5,8 +5,7 @@
   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef CALENDARSUPPORT_INCIDENCEATTACHMENTMODEL_H
-#define CALENDARSUPPORT_INCIDENCEATTACHMENTMODEL_H
+#pragma once
 
 #include <Attribute>
 #include <Item>
@@ -17,7 +16,6 @@
 
 namespace Akonadi
 {
-class Item;
 }
 
 namespace CalendarSupport
@@ -70,4 +68,3 @@ private:
 };
 }
 
-#endif
