@@ -266,7 +266,7 @@ bool KCalPrefs::thatIsMe(const QString &_email)
 void KCalPrefs::setCategoryColor(const QString &cat, const QColor &color)
 {
     Akonadi::Tag tag = d->mTagCache.getTagByName(cat);
-    auto *attr = tag.attribute<Akonadi::TagAttribute>(Akonadi::Tag::AddIfMissing);
+    auto attr = tag.attribute<Akonadi::TagAttribute>(Akonadi::Tag::AddIfMissing);
     attr->setBackgroundColor(color);
     new Akonadi::TagModifyJob(tag);
 }
@@ -277,7 +277,7 @@ QColor KCalPrefs::categoryColor(const QString &cat) const
 
     if (!cat.isEmpty()) {
         const Akonadi::Tag &tag = d->mTagCache.getTagByName(cat);
-        if (const auto *attr = tag.attribute<Akonadi::TagAttribute>()) {
+        if (const auto attr = tag.attribute<Akonadi::TagAttribute>()) {
             color = attr->backgroundColor();
         }
     }
