@@ -701,7 +701,7 @@ void CalPrintTimetable::drawAllDayBox(QPainter &p,
     int lineSpacing = p.fontMetrics().lineSpacing();
 
     if (!workDays.contains(qd)) {
-        drawShadedBox(p, BOX_BORDER_WIDTH, QColor(232, 232, 232), box);
+        drawShadedBox(p, BOX_BORDER_WIDTH, sHolidayBackground, box);
     } else {
         drawBox(p, BOX_BORDER_WIDTH, box);
     }
@@ -733,9 +733,9 @@ void CalPrintTimetable::drawAllDayBox(QPainter &p,
 }
 
 void CalPrintTimetable::drawTimeTable(QPainter &p,
-                                       const QDate &fromDate,
-                                       const QDate &toDate,
-                                       const QRect &box)
+                                       QDate fromDate,
+                                       QDate toDate,
+                                       QRect box)
 {
     QTime myFromTime = mStartTime;
     QTime myToTime = mEndTime;
@@ -951,7 +951,7 @@ void CalPrintDay::setDateRange(const QDate &from, const QDate &to)
     }
 }
 
-void CalPrintDay::drawDays(QPainter &p, const QRect &box)
+void CalPrintDay::drawDays(QPainter &p, QRect box)
 {
     const int numberOfDays = mFromDate.daysTo(mToDate) + 1;
     int vcells;
@@ -1176,8 +1176,8 @@ void CalPrintWeek::setDateRange(const QDate &from, const QDate &to)
 }
 
 void CalPrintWeek::drawWeek(QPainter &p,
-                                  const QDate &qd,
-                                  const QRect &box)
+                                  QDate qd,
+                                  QRect box)
 {
     QDate weekDate = qd;
     const bool portrait = (box.height() > box.width());
