@@ -6,8 +6,7 @@
   SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
 
-#ifndef CALENDARSUPPORT_UTILS_H
-#define CALENDARSUPPORT_UTILS_H
+#pragma once
 
 #include "calendarsupport_export.h"
 
@@ -204,7 +203,7 @@ CALENDARSUPPORT_EXPORT QString subMimeTypeForIncidence(const KCalendarCore::Inci
 /**
  * Returns a list containing work days between @p start and @end.
  */
-CALENDARSUPPORT_EXPORT QList<QDate> workDays(const QDate &start, const QDate &end);
+CALENDARSUPPORT_EXPORT QList<QDate> workDays(QDate start, QDate end);
 
 /**
  * Creates a nicely formatted toolTip string for a calendar, containing some quick,
@@ -221,7 +220,7 @@ CALENDARSUPPORT_EXPORT QString toolTipString(const Akonadi::Collection &coll, bo
 /**
  * Returns a list of holidays that occur at @param date.
  */
-CALENDARSUPPORT_EXPORT QStringList holiday(const QDate &date);
+CALENDARSUPPORT_EXPORT QStringList holiday(QDate date);
 
 CALENDARSUPPORT_EXPORT QStringList categories(const KCalendarCore::Incidence::List &incidences);
 
@@ -232,4 +231,3 @@ CALENDARSUPPORT_EXPORT bool mergeCalendar(const QString &srcFilename, const KCal
 CALENDARSUPPORT_EXPORT void createAlarmReminder(const KCalendarCore::Alarm::Ptr &alarm, KCalendarCore::IncidenceBase::IncidenceType type);
 }
 
-#endif
